# Contact us

<!-- ## For investors and sponsors

Interested investors and sponsors may contact [Xinhao Xiang via email](mailto:xhxiang@ucdavis.edu). -->

## For contributing

Contributing to the project, including report/fix bugs, add new features, improve documentation, and send feedbacks,
can all be done via the project github issue page at [https://github.com/ShaneXiangH/VQA_Toolkit/issues](https://github.com/ShaneXiangH/VQA_Toolkit/issues).

## For Licenses

`AIGVE` is an open-source project. For more information about the licenses, please refer to the [license page](license.md).